@@ -72,8 +72,11 @@ def plot_indicators(portfolio, output_path=None, filename=None, show_fig=False):
 def plot_returns(btc_acc_returns, eth_acc_returns, pf_acc_returns, start_date):
     fig, ax = plt.subplots()
     btc_acc_returns.plot(figsize=(8, 6), label='BTC')
+    ax.annotate(f'{btc_acc_returns[-1]:.2f}', (btc_acc_returns.index[-1], btc_acc_returns[-1]))
     eth_acc_returns.plot(label='ETH')
+    ax.annotate(f'{eth_acc_returns[-1]:.2f}', (eth_acc_returns.index[-1], eth_acc_returns[-1]))
     pf_acc_returns.plot(label='Portfolio')
+    ax.annotate(f'{pf_acc_returns[-1]:.2f}', (pf_acc_returns.index[-1], pf_acc_returns[-1]))
     ax.legend()
     ax.set_title(f'{start_date}-day Portfolio Return')
     fig.tight_layout()
